/*****************************************************************************
  GEDIT.CPP

  Purpose: CGlobalEdit implementation file. The CGlobalEdit uses an allocated
           global memory region instead of the applications local heap.

  Functions: CGlobalEdit::Create(DWORD dwStyle,     Creates the edit control
                                 const RECT& rect,    with a specific style
                                 CWnd* pParentWnd,
                                 UINT nID)
             CGlobalEdit::PreCreateWindow(CREATESTRUCT &cs) Allocates global
                                                              memory for the
                                                              edit control

  Development Team: Jay Potter


  Written by Microsoft Product Support Services, Languages Developer Support
  Copyright (c) 1994 Microsoft Corporation. All rights reserved.
\****************************************************************************/

#include "stdafx.h"
#include "globedit.h"
#include "gedit.h"

#ifdef _DEBUG
#undef THIS_FILE
static char BASED_CODE THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CGlobalEdit

CGlobalEdit::CGlobalEdit()
{
}

/************************************************************************
  CGlobalEdit::Create

  Purpose: Sets up a variety of styles for the edit control and then
           creates it by calling the base class

  Parameters: DWORD dwStyle     Original creation style flags
              const RECT& rect  Creation rectangle (i.e. size and position)
              CWnd* pParentWnd  The edit control's parent
              UINT nID          The control ID
              
  Returns: Nonzero if creation is successful; 0 otherwise

  Comments:

  History:

  Date     Comment                                           Initials
  ======== ================================================= ========
  5/17/94  Created                                           OJP
\***********************************************************************/
BOOL CGlobalEdit::Create(DWORD dwStyle, const RECT& rect, CWnd* pParentWnd, UINT nID)
{
    dwStyle |= (WS_CHILD | WS_VISIBLE | WS_TABSTOP | ES_MULTILINE |
                ES_AUTOVSCROLL | ES_AUTOHSCROLL | ES_LEFT | ES_WANTRETURN);
                
    BOOL bRet = CEdit::Create(dwStyle, rect, pParentWnd, nID);
    
    return bRet;
}

/************************************************************************
  CGlobalEdit::PreCreateWindow

  Purpose: Allocate a data segment from the global heap and make
           the CGlobalEdit use this segement instead of the application's
           local heap.

  Parameters: CREATESTRUCT &cs     The current (modifyable) creation
                                     structure

  Returns: Nonzero if creation should continue; 0 otherwise

  Comments:

  History:

  Date     Comment                                           Initials
  ======== ================================================= ========
  5/17/94  Created                                           OJP
\***********************************************************************/   
BOOL CGlobalEdit::PreCreateWindow(CREATESTRUCT &cs)
{
    // Allocate a shareable, moveable, zero initialized memory
    // block of size SEGMENT
    HGLOBAL ghEditDS = ::GlobalAlloc(GMEM_DDESHARE | GMEM_MOVEABLE | GMEM_ZEROINIT,
                                     SEGMENT);;
    
    // If the allocation was successful
    if (ghEditDS != NULL)
    {
        // Get a pointer to the memory
        LPVOID lpPtr = ::GlobalLock(ghEditDS);
        
        // Set up system information so that the memory can be
        // managed like a heap
        ::LocalInit(HIWORD((LONG)lpPtr), 0, (WORD)(::GlobalSize(ghEditDS) - 16));
        
        // Unlock the memory so that the system has control
        ::UnlockSegment(HIWORD((LONG)lpPtr));
        
        // Set the instance handle to the segment of the memory block.
        // Edit controls use the hInstance variable as their data segment
        // since the instance handle is also the application's DS. In this
        // case we have allocated a completely different segment and
        // used that DS instead.
        cs.hInstance = (HINSTANCE) HIWORD((LONG)lpPtr);
        return TRUE;
    }
    else
        return FALSE;
}

CGlobalEdit::~CGlobalEdit()
{
}

BEGIN_MESSAGE_MAP(CGlobalEdit, CEdit)
    //{{AFX_MSG_MAP(CGlobalEdit)
    //}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CGlobalEdit message handlers

